@@ -27,7 +27,19 @@ class FileList:
 
 
 		self.__explore(dir)
-	
+
+	def merge (self, flist):
+		if isinstance(flist, FileList):
+			flist = flist.get()
+		elif isinstance(flist, str):
+			flist = [flist]
+
+		s = set(self.__list)
+		s.update(flist)
+		self.__list = list(s)
+		
+		return self.__list
+			
 	def get (self):
 		return self.__list
 
